@@ -1,7 +1,7 @@
 package Setup::File;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1187,7 +1187,7 @@ Setup::File - Setup file (existence, mode, permission, content)
 
 =head1 VERSION
 
-This document describes version 0.21 of Setup::File (from Perl distribution Setup-File), released on 2015-08-18.
+This document describes version 0.22 of Setup::File (from Perl distribution Setup-File), released on 2015-09-04.
 
 =head1 FAQ
 
@@ -1209,15 +1209,13 @@ L<Setup::File::Symlink>
 
 =head2 chmod(%args) -> [status, msg, result, meta]
 
-{en_US Set file's permission mode}.
+Set file's permission mode.
 
-{en_US 
 Fixed state: C<path> exists and mode is already correct.
 
 Fixable state: C<path> exists but mode is not correct.
 
 Unfixable state: C<path> doesn't exist.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1228,19 +1226,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<follow_symlink> => I<bool> (default: 0)
 
-{en_US Whether to follow symlink}.
+Whether to follow symlink.
 
 =item * B<mode>* => I<str>
 
-{en_US Permission mode, either numeric or symbolic (e.g. a+w)}.
+Permission mode, either numeric or symbolic (e.g. a+w).
 
 =item * B<orig_mode> => I<int>
 
-{en_US If set, confirm if current mode is not the same as this}.
+If set, confirm if current mode is not the same as this.
 
 =item * B<path>* => I<str>
 
-{en_US Path to file/directory}.
+Path to file/directory.
 
 =back
 
@@ -1284,15 +1282,13 @@ Return value:  (any)
 
 =head2 chown(%args) -> [status, msg, result, meta]
 
-{en_US Set file's ownership}.
+Set file's ownership.
 
-{en_US 
 Fixed state: C<path> exists and ownership is already correct.
 
 Fixable state: C<path> exists but ownership is not correct.
 
 Unfixable state: C<path> doesn't exist.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1303,27 +1299,27 @@ Arguments ('*' denotes required arguments):
 
 =item * B<follow_symlink> => I<bool> (default: 0)
 
-{en_US Whether to follow symlink}.
+Whether to follow symlink.
 
 =item * B<group> => I<str>
 
-{en_US Numeric GID or group}.
+Numeric GID or group.
 
 =item * B<orig_group> => I<str>
 
-{en_US If set, confirm if current group is not the same as this}.
+If set, confirm if current group is not the same as this.
 
 =item * B<orig_owner> => I<str>
 
-{en_US If set, confirm if current owner is not the same as this}.
+If set, confirm if current owner is not the same as this.
 
 =item * B<owner> => I<str>
 
-{en_US Numeric UID or username}.
+Numeric UID or username.
 
 =item * B<path>* => I<str>
 
-{en_US Path to file/directory}.
+Path to file/directory.
 
 =back
 
@@ -1367,15 +1363,13 @@ Return value:  (any)
 
 =head2 mkdir(%args) -> [status, msg, result, meta]
 
-{en_US Create directory}.
+Create directory.
 
-{en_US 
 Fixed state: C<path> exists and is a directory.
 
 Fixable state: C<path> doesn't exist.
 
 Unfixable state: C<path> exists and is not a directory.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1386,15 +1380,15 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_symlink> => I<str>
 
-{en_US Whether to regard symlink to a directory as directory}.
+Whether to regard symlink to a directory as directory.
 
 =item * B<mode> => I<str>
 
-{en_US Set mode for the newly created directory}.
+Set mode for the newly created directory.
 
 =item * B<path>* => I<str>
 
-{en_US Path to directory}.
+Path to directory.
 
 =back
 
@@ -1438,16 +1432,14 @@ Return value:  (any)
 
 =head2 mkfile(%args) -> [status, msg, result, meta]
 
-{en_US Create file (and/or set content)}.
+Create file (and/or set content).
 
-{en_US 
 Fixed state: C<path> exists, is a file, and content is correct.
 
 Fixable state: C<path> doesn't exist. Or C<path> exists, is a file, and content is
 incorrect. Or C<orig_path> specified and exists.
 
 Unfixable state: C<path> exists and is not a file.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1458,13 +1450,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_symlink> => I<str>
 
-{en_US Whether to regard symlink to a file as file}.
+Whether to regard symlink to a file as file.
 
 =item * B<check_content_func> => I<str>
 
-{en_US Name of function to check content}.
+Name of function to check content.
 
-{en_US 
 If unset, file will not be checked for its content. If set, function will be
 called whenever file content needs to be checked. Function will be passed the
 reference to file content and should return a boolean value indicating whether
@@ -1472,34 +1463,28 @@ content is acceptable. If it returns a false value, content is deemed
 unacceptable and needs to be fixed.
 
 Alternatively you can use the simpler C<content> or C<content_md5> argument.
-}
 
 =item * B<content> => I<str>
 
-{en_US Desired file content}.
+Desired file content.
 
-{en_US 
 Alternatively you can also use C<content_md5>, or C<gen_content_func> and
 C<check_content_func>.
-}
 
 =item * B<content_md5> => I<str>
 
-{en_US Check content against MD5 hash}.
+Check content against MD5 hash.
 
-{en_US 
 MD5 hash should be expressed in hex (e.g. bed6626e019e5870ef01736b3553e570).
 
 Used when checking content of existing file.
 
 Alternatively you can also use C<content>, or C<check_content_func>.
-}
 
 =item * B<gen_content_func> => I<str>
 
-{en_US Name of function to generate content}.
+Name of function to generate content.
 
-{en_US 
 If set, whenever a new file content is needed (e.g. when file is created or file
 content reset), this function will be called to provide it. If unset, empty
 string will be used instead.
@@ -1508,11 +1493,10 @@ Function will be passed the reference to the current content (or undef) and
 should return the new content.
 
 Alternatively you can use the simpler C<content> argument.
-}
 
 =item * B<path>* => I<str>
 
-{en_US Path to file}.
+Path to file.
 
 =item * B<suffix> => I<str>
 
@@ -1558,16 +1542,14 @@ Return value:  (any)
 
 =head2 rmdir(%args) -> [status, msg, result, meta]
 
-{en_US Delete directory}.
+Delete directory.
 
-{en_US 
 Fixed state: C<path> doesn't exist.
 
 Fixable state: C<path> exists and is a directory (or, a symlink to a directory,
 if C<allow_symlink> option is enabled).
 
 Unfixable state: C<path> exists but is not a directory.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1578,20 +1560,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_symlink> => I<bool> (default: 0)
 
-{en_US Whether to regard symlink to a directory as directory}.
+Whether to regard symlink to a directory as directory.
 
 =item * B<delete_nonempty_dir> => I<bool>
 
-{en_US Whether to delete non-empty directory}.
+Whether to delete non-empty directory.
 
-{en_US 
 If set to true, will delete non-empty directory.
 
 If set to false, will never delete non-empty directory.
 
 If unset (default), will ask for confirmation first by returning status 331.
 Caller can confirm by passing special argument C<-confirm>.
-}
 
 =item * B<path>* => I<str>
 
@@ -1637,16 +1617,14 @@ Return value:  (any)
 
 =head2 rmfile(%args) -> [status, msg, result, meta]
 
-{en_US Delete file}.
+Delete file.
 
-{en_US 
 Fixed state: C<path> doesn't exist.
 
 Fixable state: C<path> exists and is a file (or, a symlink to a file, if
 C<allow_symlink> option is enabled).
 
 Unfixable state: C<path> exists but is not a file.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1657,31 +1635,27 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_symlink> => I<bool> (default: 0)
 
-{en_US Whether to regard symlink to a file as file}.
+Whether to regard symlink to a file as file.
 
 =item * B<orig_content> => I<str>
 
-{en_US If set, confirm if current content is not the same as this}.
+If set, confirm if current content is not the same as this.
 
-{en_US 
 Alternatively, you can use C<orig_content_hash>.
-}
 
 =item * B<orig_content_md5> => I<str>
 
-{en_US If set, confirm if current content MD5 hash is not the same as this}.
+If set, confirm if current content MD5 hash is not the same as this.
 
-{en_US 
 MD5 hash should be expressed in hex (e.g. bed6626e019e5870ef01736b3553e570).
 
 Alternatively, you can use C<orig_content> (for shorter content).
-}
 
 =item * B<path>* => I<str>
 
 =item * B<suffix> => I<str>
 
-{en_US Use this suffix when trashing}.
+Use this suffix when trashing.
 
 =back
 
@@ -1725,9 +1699,8 @@ Return value:  (any)
 
 =head2 setup_dir(%args) -> [status, msg, result, meta]
 
-{en_US Setup directory (existence, mode, permission)}.
+Setup directory (existence, mode, permission).
 
-{en_US 
 On do, will create directory (if it doesn't already exist) and fix its
 mode/permission.
 
@@ -1738,7 +1711,6 @@ confirmation is set to true, will delete non-empty directory.
 
 Will I<not> create intermediate directories like "mkdir -p". Create intermediate
 directories using several setup_dir() invocation.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1749,53 +1721,49 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_symlink> => I<bool> (default: 1)
 
-{en_US Whether symlink is allowed}.
+Whether symlink is allowed.
 
-{en_US 
 If existing dir is a symlink then if allow_symlink is false then it is an
 unacceptable condition (the symlink will be replaced if replace_symlink is
 true).
 
 Note: if you want to setup symlink instead, use Setup::Symlink.
-}
 
 =item * B<group> => I<str>
 
-{en_US Expected group}.
+Expected group.
 
 =item * B<mode> => I<str>
 
-{en_US Expected permission mode}.
+Expected permission mode.
 
 =item * B<owner> => I<str>
 
-{en_US Expected owner}.
+Expected owner.
 
 =item * B<path>* => I<str>
 
-{en_US Path to file}.
+Path to file.
 
 =item * B<replace_dir> => I<bool> (default: 1)
 
-{en_US Replace existing dir if it needs to be replaced}.
+Replace existing dir if it needs to be replaced.
 
 =item * B<replace_file> => I<bool> (default: 1)
 
-{en_US Replace existing file if it needs to be replaced}.
+Replace existing file if it needs to be replaced.
 
 =item * B<replace_symlink> => I<bool> (default: 1)
 
-{en_US Replace existing symlink if it needs to be replaced}.
+Replace existing symlink if it needs to be replaced.
 
 =item * B<should_exist> => I<bool>
 
-{en_US Whether dir should exist}.
+Whether dir should exist.
 
-{en_US 
 If undef, dir need not exist. If set to 0, dir must not exist and will be
 deleted if it does. If set to 1, dir must exist and will be created if it
 doesn't.
-}
 
 =back
 
@@ -1839,16 +1807,14 @@ Return value:  (any)
 
 =head2 setup_file(%args) -> [status, msg, result, meta]
 
-{en_US Setup file (existence, mode, permission, content)}.
+Setup file (existence, mode, permission, content).
 
-{en_US 
 On do, will create file (if it doesn't already exist) and correct
 mode/permission as well as content.
 
 On undo, will restore old mode/permission/content, or delete the file again if
 it was created by this function I<and> its content hasn't changed since (if
 content/ownership/mode has changed, function will request confirmation).
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -1859,21 +1825,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_symlink> => I<bool> (default: 1)
 
-{en_US Whether symlink is allowed}.
+Whether symlink is allowed.
 
-{en_US 
 If existing file is a symlink to a file then if allow_symlink is false then it
 is an unacceptable condition (the symlink will be replaced if replace_symlink is
 true).
 
 Note: if you want to setup symlink instead, use Setup::Symlink.
-}
 
 =item * B<check_content_func> => I<str>
 
-{en_US Name of function to check content}.
+Name of function to check content.
 
-{en_US 
 If unset, file will not be checked for its content. If set, function will be
 called whenever file content needs to be checked. Function will be passed the
 reference to file content and should return a boolean value indicating whether
@@ -1881,22 +1844,18 @@ content is acceptable. If it returns a false value, content is deemed
 unacceptable and needs to be fixed.
 
 Alternatively you can use the simpler C<content> argument.
-}
 
 =item * B<content> => I<str>
 
-{en_US Desired file content}.
+Desired file content.
 
-{en_US 
 Alternatively you can also use C<content_md5>, or C<check_content_func> and
 C<gen_content_func>.
-}
 
 =item * B<gen_content_func> => I<str>
 
-{en_US Name of function to generate content}.
+Name of function to generate content.
 
-{en_US 
 If set, whenever a new file content is needed (e.g. when file is created or file
 content reset), this function will be called to provide it. If unset, empty
 string will be used instead.
@@ -1905,50 +1864,45 @@ Function will be passed the reference to the current content (or undef) and
 should return the new content.
 
 Alternatively you can use the simpler C<content> argument.
-}
 
 =item * B<group> => I<str>
 
-{en_US Expected group (either numeric or group name)}.
+Expected group (either numeric or group name).
 
 =item * B<mode> => I<str>
 
-{en_US Expected permission mode}.
+Expected permission mode.
 
-{en_US 
 Mode is as supported by File::chmod. Either an octal string (e.g. '0755') or a
 symbolic mode (e.g. 'u+rw').
-}
 
 =item * B<owner> => I<str>
 
-{en_US Expected owner (either numeric or username)}.
+Expected owner (either numeric or username).
 
 =item * B<path>* => I<str>
 
-{en_US Path to file}.
+Path to file.
 
 =item * B<replace_dir> => I<bool> (default: 1)
 
-{en_US Replace existing dir if it needs to be replaced}.
+Replace existing dir if it needs to be replaced.
 
 =item * B<replace_file> => I<bool> (default: 1)
 
-{en_US Replace existing file if it needs to be replaced}.
+Replace existing file if it needs to be replaced.
 
 =item * B<replace_symlink> => I<bool> (default: 1)
 
-{en_US Replace existing symlink if it needs to be replaced}.
+Replace existing symlink if it needs to be replaced.
 
 =item * B<should_exist> => I<bool>
 
-{en_US Whether file should exist}.
+Whether file should exist.
 
-{en_US 
 If undef, file need not exist. If set to 0, file must not exist and will be
 deleted if it does. If set to 1, file must exist and will be created if it
 doesn't.
-}
 
 =back
 
